#
# spec file for package python-requests-mock
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-requests-mock
Version:        1.10.0
Release:        150400.7.6.1
Summary:        Module to mock out responses from the requests package
License:        Apache-2.0
URL:            https://github.com/jamielennox/requests-mock
Source:         https://files.pythonhosted.org/packages/source/r/requests-mock/requests-mock-%{version}.tar.gz
Patch0:         remove-mock.patch
Patch1:         fix_issues_with_urllib3_v2.patch
BuildRequires:  %{python_module fixtures}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module purl}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.3}
BuildRequires:  %{python_module requests-futures}
BuildRequires:  %{python_module six}
BuildRequires:  python-rpm-macros
%if 0%{suse_version} >= 1550 || (0%{?suse_version} == 1500 && 0%{?sle_version} >= 154000)
BuildRequires:  %{python_module dbm}
%else
BuildRequires:  python3-dbm
%endif
BuildRequires:  fdupes
Requires:       python-requests >= 2.3
Requires:       python-six
BuildArch:      noarch
%if "%python_flavor" != "python2"
Requires:       python-dbm
%endif
%python_subpackages

%description
requests-mock provides a building block to stub out the HTTP requests portions of your testing code.
You should checkout the docs for more information.

%prep
%autosetup -p1 -n requests-mock-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest tests

%files %{python_files}
%license LICENSE
%doc AUTHORS README.rst ChangeLog
%{python_sitelib}/requests_mock*

%changelog
* Wed Mar 12 2025 pablo.suarezhernandez@suse.com
- Tell urllib3 v2 to ignore content length mismatch
- Added:
  * fix_issues_with_urllib3_v2.patch
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 mcepl@suse.com
- Make calling of %%{sle15modernpython} optional.
* Wed Feb  1 2023 dmueller@suse.com
- switch to run tests with pytest
- build with all python flavors for SLE 15 SP4+
* Sat Jan  7 2023 dmueller@suse.com
- update to 1.10.0:
  * Add a release note for the RLock
  * Allow passing json\_encoder to mocking
  * Improvements to Type Hints
  * Lint fix for long line exception
  * Shorten line length of comments
  * Workaround for python2.7 not supporting lock timeout
  * Comments to explain reentrant behaviour
  * Change to use RLock and set a timeout to prevent infinite deadlocks
  * Update homepage/doc URLs of requests library
  * Add comment for pytest late loading feature
  * pytest plugin should lazy-load requests\_mock
  * Add test for threaded race condition
  * Use threading.Lock() to prevent race conditions around monkeypatching of
    get\_adapter()
  * add GitHub URL for PyPi
  * Add reset methods on the Mocker class type
  * Avoid using distutils to check pytest version
  * YAML quoting
  * Support Python 3.10
  * Minor changes to code snippet example
  * Fix DeprecationWarnings in setup.cfg keys
  * a few minor fixes and proposed changes to documentation files
  * Improve response-related param type hints
  * Explicitly indicate start of keyword-only args
  * Fix failing pytest
* Fri Jul 22 2022 steven.kowalik@suse.com
- Add patch remove-mock.patch:
  * Use unittest.mock if available.
* Sun Jun  6 2021 dmueller@suse.com
- update to 1.9.3:
  * Release note for 1.9.3 type annotations
  * Additional improvements to response matching type stubs
  * Improve MockerCore type stubs
* Tue May 18 2021 dmueller@suse.com
- update to 1.9.2:
  * Add release note for urlquote fix
  * Simple tests to ensure character encoding works
  * Use requests to quote URLs
  * Remove circleci badge from README
  * Restore py.typed file to enable types
  * Change tag pattern
  * Url Quote the path provided to the mocker
  * Use github action to push a release to PyPI (#163)
  * Release note for type hints
  * Add [PEP 484](https://www.python.org/dev/peps/pep-0484/) type hints
  * Mocker.copy: Use correct type when copying mocker
  * Run unit tests for pull requests as well
  * Add support for Python up to 3.9
  * Use Github Actions
  * Make is\_bound\_method private
  * Add release note for fixed bug
  * Correctly handle an explicit zero byte read
  * Add missing string delimiter in example
  * fix: is\_bound\_method by six
  * fix: \`session\` and \`real\_http\` cannot be used at the same time
* Wed Dec  9 2020 code@bnavigator.de
- Support TW with multiple python3 flavors
  * gh#openSUSE/python-rpm-macros#66
  * fix BuildRequires
  * fix %%python_expand $python executable replacement
* Sun Jun 14 2020 dmueller@suse.com
- update to 1.8.0:
  * Remove requests 2.3 compatibility code
  * Add release notes for reset function
  * Add release note for session scoped mock
  * Allow passing session as postiional argument
  * Create bound method instead of a wrapper
  * Added reset\_mock to \_RequestHistoryTracker and Adapter (#139)
  * doc on session Mockers
  * doc on nesting Mockers
  * fix README.rst typo
  * suggest Mocker for users unfamiliar with adapters
  * update examples to mount adapter on 'mock://'
  * fix global/session mock interactions and real\_http
  * Added installation instructions
  * Add release note for nested mocking
  * fix redirects (#105) and mock nesting (#116)
  * Mark IOReader object closed when using a stream
  * Add the default response reason if not set
  * Don't check that proxies are set in test
  * Add StackOverflow tag to README
  * Mention pytest fixture on the README
  * Add background information to pytest doc
  * docs: update examples to match Read the Docs
  * Expose real\_http as a public property
  * fix py27 error
  * easier session scoped mock
* Sun Sep 15 2019 jengelh@inai.de
- Use noun phrsae in summary.
* Tue Sep 10 2019 tchvatal@suse.com
- Update to 1.7.0:
  * support for purl
* Fri Jun  7 2019 tchvatal@suse.com
- Update dependencies
- Run also pytest tests
- Fix fdupes call
* Tue May  7 2019 pgajdos@suse.com
- version update to 1.6.0
  * Respect user provided content encoding type
  * Update minimum requests version to 2.3
  * Add testing for Python 3.7 & PyPy3
  * Drop \_matcher from request pickled state
  * Clarify the pytest configuration documentation
* Thu Mar  7 2019 tbechtold@suse.com
- update to 1.5.2:
  * Fix discovery of pytest version and default
  * Add a docstring to the pytest fixture
  * Include release note for py.test
  * Collapse CircleCI configuration
  * Support older pytest versions
  * Record value of stream parameter in request history
  * Some additional gitignores
  * Include reno in circleci publish job
  * Prefer readthedocs.io instead of readthedocs.org for doc links
  * Add release note describe repository migration
  * Add pytest plugin
  * Include release-notes in documentation
  * Another attempt at circleci tags
  * Only try and push to pypi on a tag
  * Update all pypi.python.org URLs to pypi.org
  * Add pypi upload configuration to circleci
  * Move tests outside of package to top level directory
  * Remove zuul.yaml as we're not using zuul anymore
  * Add CircleCI badge to README
  * Remove links to launchpad bug reporting
  * Remove .gitreview
  * Unpin sphinx dependency
  * Add circleci testing configuration
  * Use set literals throughout project
  * Prefer https:// links over http:// in docs and comments
  * Fix last\_request examples
  * Fix spelling mistakes
  * Move Zuul jobs in-tree
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Fri Feb 23 2018 tbechtold@suse.com
- update to 1.4.0:
  * allow an adapter to be passed to a Mocker object
  * Rename [wheel] section to [bdist\_wheel] as the former is legacy
  * Include license file in the generated wheel package
  * Add testing for newer Python versions 3.5 and 3.6
  * Return a separate copy for each call to decorator
  * Add string representation to \_RequestObjectProxy
* Wed Jun 14 2017 dmueller@suse.com
- fix build for SLE12
* Sat Jun 10 2017 dmueller@suse.com
- update to 1.3.0:
  * Add a releasenote for additional_matcher
  * Add documentation for the exception response
  * Fix occurences of `adatper`
  * Type check the empty string when creating repsonse
  * Allow arbirtrary matcher to be add to match
* Thu May 25 2017 sebix+novell.com@sebix.at
- convert to singlespec
* Mon Jan 30 2017 tbechtold@suse.com
- update to 1.2.0:
  * Allow for nested mocking
  * Use create_response for fake http response in tests
  * Add hostname and port properties to request
  * Move request code and tests into their own files
  * Add called_once to Mocker
  * Fix docs building
  * Fix exception message when creating a response
* Wed Sep 28 2016 tbechtold@suse.com
- update to 1.1.0:
  * Add a called_once property to adapter
  * Enable case sensitive matching
  * Provide fixture extras for pip
  * Allow doing real_http per mock via the mocker
  * Return b'' when reading closed response
  * Fixture documentation error
* Fri Jul  8 2016 dmueller@suse.com
- fix source url
* Wed Jul  6 2016 tbechtold@suse.com
- update to 1.0.0:
  * Add tox environment to run against master requests
  * Change dev status classifier to stable
  * Doc fixups
  * Expose cert and proxies as attributes of the last request
  * Add timeout and allow_retries to RequestProxy
  * Fix py34 DB issue and remove py33/py26
  * Remove pypip.in badge from readme
* Fri Dec  4 2015 dmueller@suse.com
- update to 0.7.0:
  * Support Cookies
  * Expose Fake objects in compat
  * Update .gitreview for new namespace
  * Change ignore-errors to ignore_errors
* Mon Apr 20 2015 tbechtold@suse.com
- Fix license string
* Mon Feb  2 2015 dmueller@suse.com
- update 0.6.0:
  * Update docs
  * Allow to decorate class with mock
  * Use weakref to hold matcher
  * Include matcher in request history
  * Add called and call_count to mocker
  * Update README to use newer syntax
  * Allow specifying an exception to raise
  * Update novaclient and keystoneclient git repo
  * Add pbr to all tox environments
  * Add docs environment to tox.ini
  * Work toward Python 3.4 support and testing
  * Run tip tests against requests master as well
  * Add link to find bug tracker
* Fri Sep 26 2014 tbechtold@suse.com
- Initial package
